
#line 3 "<stdout>"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char yytext[];

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	if ( yyleng >= YYLMAX ) \
		YY_FATAL_ERROR( "token too large, exceeds YYLMAX" ); \
	yy_flex_strncpy( yytext, (yytext_ptr), yyleng + 1 ); \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 17
#define YY_END_OF_BUFFER 18
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[444] =
    {   0,
        0,    0,   18,   16,   15,   15,   12,   12,   16,   12,
       12,   12,   12,   12,   12,   16,   16,   16,   16,   16,
       16,   16,   16,   16,   16,   15,    0,   12,   12,   14,
        0,    0,    0,   12,    0,    0,   12,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   10,    0,
        0,    0,    0,    0,    0,    0,   12,   12,   14,    7,
        0,    0,    0,    0,    0,    4,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   11,    0,

        0,    0,    0,    0,   12,    0,    0,    0,    0,    0,
       11,    0,    0,    0,    0,    0,    0,    0,    6,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       13,    0,    0,    6,    0,    0,    0,    0,    0,    0,
        0,    3,    0,    9,    6,    0,    0,    5,    0,    0,
        0,    0,    0,    0,   13,    0,    0,    0,    0,    0,
        0,    0,    0,    9,    0,    0,    0,    0,    0,    8,
        0,   13,    0,    0,    0,    0,    0,    9,    0,    0,
        0,    0,    0,    0,    2,    8,   13,    1,    0,    9,
        0,    0,    0,    0,    0,    0,    8,   13,    0,    9,

        0,    0,   10,    0,    0,    0,   13,    0,    9,    0,
        0,    0,    0,    0,   13,    0,    9,    0,    0,    0,
       13,    0,    9,    0,    0,   13,    9,    0,    0,   13,
        9,   13,    9,   13,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,

        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,

        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    4,    5,    1,    6,    6,    7,
        6,    6,    6,    8,    6,    6,    6,    9,    1,    1,
        1,    1,    1,    1,   10,   10,   10,   10,   10,   10,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
        1,   12,    1,    1,    1,    1,   13,   14,   15,   16,

       17,   18,   19,   20,   21,   11,   22,   23,   24,   25,
       26,   27,   28,   29,   30,   31,   32,   33,   34,   11,
       11,   35,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[36] =
    {   0,
        1,    1,    1,    2,    3,    4,    4,    4,    5,    4,
        2,    6,    4,    4,    4,    4,    4,    4,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2
    } ;

static yyconst flex_int16_t yy_base[680] =
    {   0,
        0,    0, 1198, 1199,   34,   36,   35, 1192,    0,   39,
       40,   41,   47,   42,   44,   29,   67, 1176, 1182, 1179,
     1180,   86, 1174, 1161, 1174,   51,   69,   73, 1184,    0,
     1175, 1165, 1160,   43, 1172, 1171,   51, 1168, 1152, 1161,
     1157, 1166, 1163, 1162, 1156, 1158, 1142, 1160,   25, 1147,
       85, 1146, 1153, 1139, 1147, 1133, 1135, 1135, 1199, 1151,
     1136, 1148, 1130, 1146, 1142,   80, 1153, 1152,    0, 1199,
     1126, 1124, 1128, 1126, 1136, 1199, 1124, 1128, 1132, 1131,
     1131, 1116, 1132, 1119, 1119, 1113, 1133, 1135, 1109, 1122,
     1107, 1123, 1122, 1130, 1112, 1119, 1110, 1114, 1199, 1104,

     1101, 1094,   97,  106,    0, 1105,   42, 1101,   94, 1108,
     1090, 1093, 1096, 1104, 1098, 1091, 1100, 1085, 1199,    0,
     1094, 1090, 1099, 1086, 1095, 1093, 1105, 1087,  117, 1102,
        0, 1071, 1076,  104, 1088, 1069, 1073, 1093, 1075, 1086,
     1069, 1199,   99,    0, 1093, 1079, 1069, 1199, 1065, 1062,
     1063, 1076,  121,  125,    0, 1073, 1070, 1059, 1056, 1069,
     1061, 1068, 1049,    0,  120, 1056, 1077, 1063, 1062,  131,
     1073,    0, 1047, 1059, 1055, 1043, 1056,    0, 1046, 1050,
     1044, 1038, 1044, 1036, 1199,  134,    0, 1199, 1035,    0,
     1039, 1034, 1046, 1046, 1048, 1031, 1199,    0, 1030,    0,

     1027, 1035, 1199, 1039, 1025, 1033,    0, 1032,    0, 1039,
      137, 1018, 1028, 1032,    0, 1031,    0, 1018, 1025, 1015,
        0, 1014,    0,  145,  142,    0,    0,  120,  132,    0,
        0,    0,    0, 1199,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0, 1199, 1199,  149,  152,  156,  159,  163,  144,  166,
      143,  170,  142,  174,  131,  178,  115,  182,  112,  186,
       92,  190,   89,  194,   87,  198,   85,  202,   67,  206,
       56,  210,  214,  218,  222,  226,  230,  234,  238,  242,
      246,  250,  254,  258,  262,  266,  270,  274,  278,  282,
      286,  290,  294,  298,  302,  306,  310,  314,  318,  322,

      326,  330,  334,  338,  342,  346,  350,  354,  358,  362,
      366,  370,  374,  378,  382,  386,  390,  394,  398,  402,
      406,  410,  414,  418,  422,  426,  430,  434,  438,  442,
      446,  450,  454,  458,  462,  466,  470,  474,  478,  482,
      486,  490,  494,  498,  502,  506,  510,  514,  518,  522,
      526,  530,  534,  538,  542,  546,  550,  554,  558,  562,
      566,  570,  574,  578,  582,  586,  590,  594,  598,  602,
      606,  610,  614,  618,  622,  626,  630,  634,  638,  642,
      646,  650,  654,  658,  662,  666,  670,  674,  678,  682,
      686,  690,  694,  698,  702,  706,  710,  714,  718,  722,

      726,  730,  734,  738,  742,  746,  750,  754,  758,  762,
      766,  770,  774,  778,  782,  786,  790,  794,  798,  802,
      806,  810,  814,  818,  822,  826,  830,  834,  838,  842,
      846,  850,  854,  858,  862,  866,  870,  874,  878,  882,
      886,  890,  894,  898,  902,  906,  910,  914,  918,  922,
      926,  930,  934,  938,  942,  946,  950,  954,  958,  962,
      966,  970,  974,  978,  982,  986,  990,  994,  998, 1002,
     1006, 1010, 1014, 1018, 1022, 1026, 1030, 1034, 1038
    } ;

static yyconst flex_int16_t yy_def[680] =
    {   0,
      443,    1,  443,  443,  443,  443,  444,  444,  445,  444,
      444,  444,  444,  444,  444,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  446,  446,  447,
      443,  443,  443,  446,  443,  443,  446,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  448,  448,  447,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,

      443,  443,  443,  443,  449,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  450,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      451,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  452,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  453,  443,  443,  443,  443,  443,
      443,  443,  443,  454,  443,  443,  443,  443,  443,  443,
      443,  455,  443,  443,  443,  443,  443,  456,  443,  443,
      443,  443,  443,  443,  443,  443,  457,  443,  443,  458,
      443,  443,  443,  443,  443,  443,  443,  459,  443,  460,

      443,  443,  443,  443,  443,  443,  461,  443,  462,  443,
      443,  443,  443,  443,  463,  443,  464,  443,  443,  443,
      465,  443,  466,  443,  443,  467,  468,  443,  443,  469,
      470,  471,  472,  443,  473,  474,  475,  476,  477,  478,
      479,  480,  481,  482,  483,  484,  485,  486,  487,  488,
      489,  490,  491,  492,  493,  494,  495,  496,  497,  498,
      499,  500,  501,  502,  503,  504,  505,  506,  507,  508,
      509,  510,  511,  512,  513,  514,  515,  516,  517,  518,
      519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
      529,  530,  531,  532,  533,  534,  535,  536,  537,  538,

      539,  540,  541,  542,  543,  544,  545,  546,  547,  548,
      549,  550,  551,  552,  553,  554,  555,  556,  557,  558,
      559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
      569,  570,  571,  572,  573,  574,  575,  576,  577,  578,
      579,  580,  581,  582,  583,  584,  585,  586,  587,  588,
      589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
      599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
      609,  610,  611,  612,  613,  614,  615,  616,  617,  618,
      619,  620,  621,  622,  623,  624,  625,  626,  627,  628,
      629,  630,  631,  632,  633,  634,  635,  636,  637,  638,

      639,  640,  641,  642,  643,  644,  645,  646,  647,  648,
      649,  650,  651,  652,  653,  654,  655,  656,  657,  658,
      659,  660,  661,  662,  663,  664,  665,  666,  667,  668,
      669,  670,  671,  672,  673,  674,  675,  676,  677,  678,
      679,  443,    0,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,

      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,

      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443
    } ;

static yyconst flex_int16_t yy_nxt[1235] =
    {   0,
        4,    5,    6,    4,    4,    7,    7,    7,    4,    8,
        4,    9,   10,   11,   12,   13,   14,   15,   16,    4,
       17,    4,   18,    4,   19,    4,   20,    4,   21,   22,
       23,   24,   25,    4,    4,   26,   26,   26,   26,   27,
       28,   28,   28,  443,  443,  443,  443,  443,  443,   42,
       86,  443,   26,   26,  133,  443,   34,   87,   43,  234,
       35,   36,   32,   37,   41,   33,   38,   39,  134,   31,
      232,   73,   40,   44,   66,   66,   66,   27,   67,   67,
       67,   45,   46,   76,  103,  104,  104,  104,  230,   47,
      226,   48,  221,   49,   50,  215,   51,   52,   57,   89,

       58,   59,  129,  129,  129,   90,   60,  158,   61,   91,
      103,  130,  130,  130,  135,  207,  159,   62,  198,  162,
      136,  153,  154,  154,  154,  163,  170,  170,  170,  153,
      171,  171,  171,  179,  187,  180,  186,  186,  186,  197,
      197,  197,  203,  203,  203,  172,  155,  131,  188,  188,
      181,   29,   29,   30,   30,   30,  229,   30,   68,   68,
       69,   69,   69,  228,   69,  105,  105,  144,  144,  144,
      144,  164,  164,  164,  164,  178,  178,  178,  178,  190,
      190,  190,  190,  200,  200,  200,  200,  209,  209,  209,
      209,  217,  217,  217,  217,  223,  223,  223,  223,  227,

      227,  227,  227,  231,  231,  231,  231,  233,  233,  233,
      233,  235,  235,  235,  235,  236,  236,  236,  236,  237,
      237,  237,  237,  238,  238,  238,  238,  239,  239,  239,
      239,  240,  240,  240,  240,  241,  241,  241,  241,  242,
      242,  242,  242,  243,  243,  243,  243,  244,  244,  244,
      244,  245,  245,  245,  245,  246,  246,  246,  246,  247,
      247,  247,  247,  248,  248,  248,  248,  249,  249,  249,
      249,  250,  250,  250,  250,  251,  251,  251,  251,  252,
      252,  252,  252,  253,  253,  253,  253,  254,  254,  254,
      254,  255,  255,  255,  255,  256,  256,  256,  256,  257,

      257,  257,  257,  258,  258,  258,  258,  259,  259,  259,
      259,  260,  260,  260,  260,  261,  261,  261,  261,  262,
      262,  262,  262,  263,  263,  263,  263,  264,  264,  264,
      264,  265,  265,  265,  265,  266,  266,  266,  266,  267,
      267,  267,  267,  268,  268,  268,  268,  269,  269,  269,
      269,  270,  270,  270,  270,  271,  271,  271,  271,  272,
      272,  272,  272,  273,  273,  273,  273,  274,  274,  274,
      274,  275,  275,  275,  275,  276,  276,  276,  276,  277,
      277,  277,  277,  278,  278,  278,  278,  279,  279,  279,
      279,  280,  280,  280,  280,  281,  281,  281,  281,  282,

      282,  282,  282,  283,  283,  283,  283,  284,  284,  284,
      284,  285,  285,  285,  285,  286,  286,  286,  286,  287,
      287,  287,  287,  288,  288,  288,  288,  289,  289,  289,
      289,  290,  290,  290,  290,  291,  291,  291,  291,  292,
      292,  292,  292,  293,  293,  293,  293,  294,  294,  294,
      294,  295,  295,  295,  295,  296,  296,  296,  296,  297,
      297,  297,  297,  298,  298,  298,  298,  299,  299,  299,
      299,  300,  300,  300,  300,  301,  301,  301,  301,  302,
      302,  302,  302,  303,  303,  303,  303,  304,  304,  304,
      304,  305,  305,  305,  305,  306,  306,  306,  306,  307,

      307,  307,  307,  308,  308,  308,  308,  309,  309,  309,
      309,  310,  310,  310,  310,  311,  311,  311,  311,  312,
      312,  312,  312,  313,  313,  313,  313,  314,  314,  314,
      314,  315,  315,  315,  315,  316,  316,  316,  316,  317,
      317,  317,  317,  318,  318,  318,  318,  319,  319,  319,
      319,  320,  320,  320,  320,  321,  321,  321,  321,  322,
      322,  322,  322,  323,  323,  323,  323,  324,  324,  324,
      324,  325,  325,  325,  325,  326,  326,  326,  326,  327,
      327,  327,  327,  328,  328,  328,  328,  329,  329,  329,
      329,  330,  330,  330,  330,  331,  331,  331,  331,  332,

      332,  332,  332,  333,  333,  333,  333,  334,  334,  334,
      334,  335,  335,  335,  335,  336,  336,  336,  336,  337,
      337,  337,  337,  338,  338,  338,  338,  339,  339,  339,
      339,  340,  340,  340,  340,  341,  341,  341,  341,  342,
      342,  342,  342,  343,  343,  343,  343,  344,  344,  344,
      344,  345,  345,  345,  345,  346,  346,  346,  346,  347,
      347,  347,  347,  348,  348,  348,  348,  349,  349,  349,
      349,  350,  350,  350,  350,  351,  351,  351,  351,  352,
      352,  352,  352,  353,  353,  353,  353,  354,  354,  354,
      354,  355,  355,  355,  355,  356,  356,  356,  356,  357,

      357,  357,  357,  358,  358,  358,  358,  359,  359,  359,
      359,  360,  360,  360,  360,  361,  361,  361,  361,  362,
      362,  362,  362,  363,  363,  363,  363,  364,  364,  364,
      364,  365,  365,  365,  365,  366,  366,  366,  366,  367,
      367,  367,  367,  368,  368,  368,  368,  369,  369,  369,
      369,  370,  370,  370,  370,  371,  371,  371,  371,  372,
      372,  372,  372,  373,  373,  373,  373,  374,  374,  374,
      374,  375,  375,  375,  375,  376,  376,  376,  376,  377,
      377,  377,  377,  378,  378,  378,  378,  379,  379,  379,
      379,  380,  380,  380,  380,  381,  381,  381,  381,  382,

      382,  382,  382,  383,  383,  383,  383,  384,  384,  384,
      384,  385,  385,  385,  385,  386,  386,  386,  386,  387,
      387,  387,  387,  388,  388,  388,  388,  389,  389,  389,
      389,  390,  390,  390,  390,  391,  391,  391,  391,  392,
      392,  392,  392,  393,  393,  393,  393,  394,  394,  394,
      394,  395,  395,  395,  395,  396,  396,  396,  396,  397,
      397,  397,  397,  398,  398,  398,  398,  399,  399,  399,
      399,  400,  400,  400,  400,  401,  401,  401,  401,  402,
      402,  402,  402,  403,  403,  403,  403,  404,  404,  404,
      404,  405,  405,  405,  405,  406,  406,  406,  406,  407,

      407,  407,  407,  408,  408,  408,  408,  409,  409,  409,
      409,  410,  410,  410,  410,  411,  411,  411,  411,  412,
      412,  412,  412,  413,  413,  413,  413,  414,  414,  414,
      414,  415,  415,  415,  415,  416,  416,  416,  416,  417,
      417,  417,  417,  418,  418,  418,  418,  419,  419,  419,
      419,  420,  420,  420,  420,  421,  421,  421,  421,  422,
      422,  422,  422,  423,  423,  423,  423,  424,  424,  424,
      424,  425,  425,  425,  425,  426,  426,  426,  426,  427,
      427,  427,  427,  428,  428,  428,  428,  429,  429,  429,
      429,  430,  430,  430,  430,  431,  431,  431,  431,  432,

      432,  432,  432,  433,  433,  433,  433,  434,  434,  434,
      434,  435,  435,  435,  435,  436,  436,  436,  436,  437,
      437,  437,  437,  438,  438,  438,  438,  439,  439,  439,
      439,  440,  440,  440,  440,  441,  441,  441,  441,  442,
      442,  442,  442,   99,   99,  225,  224,  222,  220,   99,
      219,  218,  216,  214,  213,  212,  211,  210,  208,  206,
      205,  204,  203,  202,  201,  199,  196,  195,  194,  193,
      192,  191,   99,   59,  188,  189,  188,  153,  185,  184,
      183,  182,   99,   99,  177,  176,  175,  174,  173,   99,
      169,  168,  167,   99,  166,   99,  165,   99,  161,  160,

      119,   99,   99,   99,  157,  156,  103,  152,  151,  150,
      149,  148,  147,  146,  145,   99,   99,  143,  142,  141,
      140,  139,  138,  137,   59,  132,  128,  127,  126,  125,
       70,   70,  124,  123,   70,  122,   99,   99,  121,  120,
      119,  118,  117,   99,  116,  115,  114,  113,  112,   59,
      111,  110,  109,  108,  107,  106,  443,   27,  102,   70,
      101,  100,   99,   98,   97,   96,   95,   70,   94,   93,
       92,   88,   85,   84,   70,   83,   70,   82,   81,   80,
       79,   78,   77,   75,   74,   72,   71,   70,  443,   65,
       64,   63,   56,   55,   54,   53,  443,  443,    3,  443,

      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443
    } ;

static yyconst flex_int16_t yy_chk[1235] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    5,    5,    6,    6,    7,
        7,    7,    7,   10,   11,   12,   14,   34,   15,   16,
       49,   13,   26,   26,  107,   37,   12,   49,   16,  471,
       12,   12,   11,   13,   15,   11,   13,   13,  107,   10,
      469,   34,   14,   17,   27,   27,   27,   28,   28,   28,
       28,   17,   17,   37,   66,   66,   66,   66,  467,   17,
      465,   17,  463,   17,   17,  461,   17,   17,   22,   51,

       22,   22,  103,  103,  103,   51,   22,  134,   22,   51,
      104,  104,  104,  104,  109,  459,  134,   22,  457,  143,
      109,  129,  129,  129,  129,  143,  153,  153,  153,  154,
      154,  154,  154,  165,  455,  165,  170,  170,  170,  186,
      186,  186,  211,  211,  211,  453,  451,  449,  229,  228,
      165,  444,  444,  445,  445,  445,  225,  445,  446,  446,
      447,  447,  447,  224,  447,  448,  448,  450,  450,  450,
      450,  452,  452,  452,  452,  454,  454,  454,  454,  456,
      456,  456,  456,  458,  458,  458,  458,  460,  460,  460,
      460,  462,  462,  462,  462,  464,  464,  464,  464,  466,

      466,  466,  466,  468,  468,  468,  468,  470,  470,  470,
      470,  472,  472,  472,  472,  473,  473,  473,  473,  474,
      474,  474,  474,  475,  475,  475,  475,  476,  476,  476,
      476,  477,  477,  477,  477,  478,  478,  478,  478,  479,
      479,  479,  479,  480,  480,  480,  480,  481,  481,  481,
      481,  482,  482,  482,  482,  483,  483,  483,  483,  484,
      484,  484,  484,  485,  485,  485,  485,  486,  486,  486,
      486,  487,  487,  487,  487,  488,  488,  488,  488,  489,
      489,  489,  489,  490,  490,  490,  490,  491,  491,  491,
      491,  492,  492,  492,  492,  493,  493,  493,  493,  494,

      494,  494,  494,  495,  495,  495,  495,  496,  496,  496,
      496,  497,  497,  497,  497,  498,  498,  498,  498,  499,
      499,  499,  499,  500,  500,  500,  500,  501,  501,  501,
      501,  502,  502,  502,  502,  503,  503,  503,  503,  504,
      504,  504,  504,  505,  505,  505,  505,  506,  506,  506,
      506,  507,  507,  507,  507,  508,  508,  508,  508,  509,
      509,  509,  509,  510,  510,  510,  510,  511,  511,  511,
      511,  512,  512,  512,  512,  513,  513,  513,  513,  514,
      514,  514,  514,  515,  515,  515,  515,  516,  516,  516,
      516,  517,  517,  517,  517,  518,  518,  518,  518,  519,

      519,  519,  519,  520,  520,  520,  520,  521,  521,  521,
      521,  522,  522,  522,  522,  523,  523,  523,  523,  524,
      524,  524,  524,  525,  525,  525,  525,  526,  526,  526,
      526,  527,  527,  527,  527,  528,  528,  528,  528,  529,
      529,  529,  529,  530,  530,  530,  530,  531,  531,  531,
      531,  532,  532,  532,  532,  533,  533,  533,  533,  534,
      534,  534,  534,  535,  535,  535,  535,  536,  536,  536,
      536,  537,  537,  537,  537,  538,  538,  538,  538,  539,
      539,  539,  539,  540,  540,  540,  540,  541,  541,  541,
      541,  542,  542,  542,  542,  543,  543,  543,  543,  544,

      544,  544,  544,  545,  545,  545,  545,  546,  546,  546,
      546,  547,  547,  547,  547,  548,  548,  548,  548,  549,
      549,  549,  549,  550,  550,  550,  550,  551,  551,  551,
      551,  552,  552,  552,  552,  553,  553,  553,  553,  554,
      554,  554,  554,  555,  555,  555,  555,  556,  556,  556,
      556,  557,  557,  557,  557,  558,  558,  558,  558,  559,
      559,  559,  559,  560,  560,  560,  560,  561,  561,  561,
      561,  562,  562,  562,  562,  563,  563,  563,  563,  564,
      564,  564,  564,  565,  565,  565,  565,  566,  566,  566,
      566,  567,  567,  567,  567,  568,  568,  568,  568,  569,

      569,  569,  569,  570,  570,  570,  570,  571,  571,  571,
      571,  572,  572,  572,  572,  573,  573,  573,  573,  574,
      574,  574,  574,  575,  575,  575,  575,  576,  576,  576,
      576,  577,  577,  577,  577,  578,  578,  578,  578,  579,
      579,  579,  579,  580,  580,  580,  580,  581,  581,  581,
      581,  582,  582,  582,  582,  583,  583,  583,  583,  584,
      584,  584,  584,  585,  585,  585,  585,  586,  586,  586,
      586,  587,  587,  587,  587,  588,  588,  588,  588,  589,
      589,  589,  589,  590,  590,  590,  590,  591,  591,  591,
      591,  592,  592,  592,  592,  593,  593,  593,  593,  594,

      594,  594,  594,  595,  595,  595,  595,  596,  596,  596,
      596,  597,  597,  597,  597,  598,  598,  598,  598,  599,
      599,  599,  599,  600,  600,  600,  600,  601,  601,  601,
      601,  602,  602,  602,  602,  603,  603,  603,  603,  604,
      604,  604,  604,  605,  605,  605,  605,  606,  606,  606,
      606,  607,  607,  607,  607,  608,  608,  608,  608,  609,
      609,  609,  609,  610,  610,  610,  610,  611,  611,  611,
      611,  612,  612,  612,  612,  613,  613,  613,  613,  614,
      614,  614,  614,  615,  615,  615,  615,  616,  616,  616,
      616,  617,  617,  617,  617,  618,  618,  618,  618,  619,

      619,  619,  619,  620,  620,  620,  620,  621,  621,  621,
      621,  622,  622,  622,  622,  623,  623,  623,  623,  624,
      624,  624,  624,  625,  625,  625,  625,  626,  626,  626,
      626,  627,  627,  627,  627,  628,  628,  628,  628,  629,
      629,  629,  629,  630,  630,  630,  630,  631,  631,  631,
      631,  632,  632,  632,  632,  633,  633,  633,  633,  634,
      634,  634,  634,  635,  635,  635,  635,  636,  636,  636,
      636,  637,  637,  637,  637,  638,  638,  638,  638,  639,
      639,  639,  639,  640,  640,  640,  640,  641,  641,  641,
      641,  642,  642,  642,  642,  643,  643,  643,  643,  644,

      644,  644,  644,  645,  645,  645,  645,  646,  646,  646,
      646,  647,  647,  647,  647,  648,  648,  648,  648,  649,
      649,  649,  649,  650,  650,  650,  650,  651,  651,  651,
      651,  652,  652,  652,  652,  653,  653,  653,  653,  654,
      654,  654,  654,  655,  655,  655,  655,  656,  656,  656,
      656,  657,  657,  657,  657,  658,  658,  658,  658,  659,
      659,  659,  659,  660,  660,  660,  660,  661,  661,  661,
      661,  662,  662,  662,  662,  663,  663,  663,  663,  664,
      664,  664,  664,  665,  665,  665,  665,  666,  666,  666,
      666,  667,  667,  667,  667,  668,  668,  668,  668,  669,

      669,  669,  669,  670,  670,  670,  670,  671,  671,  671,
      671,  672,  672,  672,  672,  673,  673,  673,  673,  674,
      674,  674,  674,  675,  675,  675,  675,  676,  676,  676,
      676,  677,  677,  677,  677,  678,  678,  678,  678,  679,
      679,  679,  679,  222,  220,  219,  218,  216,  214,  213,
      212,  210,  208,  206,  205,  204,  202,  201,  199,  196,
      195,  194,  193,  192,  191,  189,  184,  183,  182,  181,
      180,  179,  177,  176,  175,  174,  173,  171,  169,  168,
      167,  166,  163,  162,  161,  160,  159,  158,  157,  156,
      152,  151,  150,  149,  147,  146,  145,  141,  140,  139,

      138,  137,  136,  135,  133,  132,  130,  128,  127,  126,
      125,  124,  123,  122,  121,  118,  117,  116,  115,  114,
      113,  112,  111,  110,  108,  106,  102,  101,  100,   98,
       97,   96,   95,   94,   93,   92,   91,   90,   89,   88,
       87,   86,   85,   84,   83,   82,   81,   80,   79,   78,
       77,   75,   74,   73,   72,   71,   68,   67,   65,   64,
       63,   62,   61,   60,   58,   57,   56,   55,   54,   53,
       52,   50,   48,   47,   46,   45,   44,   43,   42,   41,
       40,   39,   38,   36,   35,   33,   32,   31,   29,   25,
       24,   23,   21,   20,   19,   18,    8,    3,  443,  443,

      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#ifndef YYLMAX
#define YYLMAX 8192
#endif

char yytext[YYLMAX];
char *yytext_ptr;
#line 1 "prom_lex.l"
/*
 * Copyright (C) IBM Corporation. 2007
 * Author: Doug Maxey <dwm@austin.ibm.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
/* definitions */
#line 23 "prom_lex.l"
#include "prom_parse.h"

#undef LEXDEBUG
#ifdef LEXDEBUG
#define dbg(a) dbgprint((a))
#else
#define dbg(a) do {} while (0)
#endif  /* LEXDEBUG */

#define upval(d)				\
    dbg(#d);					\
    yylval.str[0] = 0;                          \
    strcat(yylval.str, yytext);			\
    yylloc.first_column = yylloc.last_column;	\
    yylloc.last_column += yyleng;		\
    return d

void dbgprint(const char *item) { fprintf(stderr, "%s: \"%s\" len=%d ", item, yytext, yyleng);}

#define YY_NO_INPUT 1
/* CHOSEN uses only boot related paths. */
#line 975 "<stdout>"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

int yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 65 "prom_lex.l"


#line 1163 "<stdout>"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 444 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 443 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 67 "prom_lex.l"
{ upval(CHOSEN); }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 68 "prom_lex.l"
{ upval(VDEVICE); }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 69 "prom_lex.l"
{ upval(VDEVINST); }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 70 "prom_lex.l"
{ upval(VDEVDEV); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 71 "prom_lex.l"
{ upval(VDEVRAW); }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 72 "prom_lex.l"
{ upval(OBPQUAL); }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 73 "prom_lex.l"
{ upval(BUSNAME); }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 74 "prom_lex.l"
{ upval(IPV4); }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 75 "prom_lex.l"
{ upval(IQN); }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 76 "prom_lex.l"
{ upval(BOOTDEV); }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 77 "prom_lex.l"
{ upval(OBPPARM); }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 78 "prom_lex.l"
{ upval(HEX4); }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 79 "prom_lex.l"
{ upval(HEX16); }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 80 "prom_lex.l"
{ upval(FILENAME); }
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 81 "prom_lex.l"
{                  /* eat all whitespace. */
	yylloc.first_column = yylloc.last_column;
	yylloc.last_column += yyleng;
}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 85 "prom_lex.l"
{			/* any other single char. */
	dbg("??");
	yylloc.first_column = yylloc.last_column;
	yylloc.last_column += yyleng;
	return *yytext;
}
	YY_BREAK
case YY_STATE_EOF(INITIAL):
#line 92 "prom_lex.l"
yyterminate();
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 93 "prom_lex.l"
ECHO;
	YY_BREAK
#line 1340 "<stdout>"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 444 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 444 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 443);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 93 "prom_lex.l"



